@@ -103,19 +103,21 @@ class SwiftStorage(_carbonara.CarbonaraBasedStorage):
 
     def _list_metric_with_measures_to_process(self):
         headers, files = self.swift.get_container(self.MEASURE_PREFIX,
-                                                  delimiter='/')
+                                                  delimiter='/',
+                                                  full_listing=True)
         return set(f['subdir'][:-1] for f in files if 'subdir' in f)
 
     def _list_measure_files_for_metric_id(self, metric_id):
         headers, files = self.swift.get_container(
-            self.MEASURE_PREFIX, path=six.text_type(metric_id))
+            self.MEASURE_PREFIX, path=six.text_type(metric_id),
+            full_listing=True)
         return files
 
     def _pending_measures_to_process_count(self, metric_id):
         return len(self._list_measure_files_for_metric_id(metric_id))
 
     def _delete_unprocessed_measures_for_metric_id(self, metric_id):
-        files = self._list_measure_files_for_metric(metric_id)
+        files = self._list_measure_files_for_metric_id(metric_id)
         for f in files:
             self.swift.delete_object(self.MEASURE_PREFIX, f['name'])
 
